--ThinkSQL RDBMS restaurant demonstration schema
--(C)Copyright 2000-2004, ThinkSQL Ltd.

--Note: you must be connected as ADMIN to have privilege to CREATE USERs and SCHEMAs authorized by others

--First create a new user to own the schema
CREATE USER RESTAURANT;	--this is non-standard SQL

--Create the schema (this will set the new user's default schema to this new schema)
CREATE SCHEMA RESTAURANT AUTHORIZATION RESTAURANT
	CREATE TABLE MENU_ITEM_GROUP (MENU_ITEM_GROUP_NO INTEGER NOT NULL,
		MENU_ITEM_GROUP_NAME VARCHAR(20),
		PRIMARY KEY (MENU_ITEM_GROUP_NO) )
		
	CREATE TABLE MENU_ITEM (MENU_ITEM_NO INTEGER NOT NULL,
		MENU_ITEM_NAME VARCHAR(40),
		MENU_ITEM_GROUP_NO INTEGER,
		PRICE DECIMAL(6,2),
		PRIMARY KEY (MENU_ITEM_NO),
		FOREIGN KEY (MENU_ITEM_GROUP_NO) REFERENCES MENU_ITEM_GROUP (MENU_ITEM_GROUP_NO) )

	CREATE TABLE "SERVER" (SERVER_NO INTEGER NOT NULL,
		SERVER_NAME VARCHAR(20),
		PRIMARY KEY (SERVER_NO) )
		
	CREATE TABLE CHECK_HEADER (CHECK_NO INTEGER NOT NULL,
		SERVER_NO INTEGER REFERENCES "SERVER",
		START_TIME TIMESTAMP(0),
		PRIMARY KEY (CHECK_NO) )

	CREATE TABLE CHECK_DETAIL (CHECK_NO INTEGER NOT NULL REFERENCES CHECK_HEADER,
		LINE_NO INTEGER NOT NULL,
		MENU_ITEM_NO INTEGER REFERENCES MENU_ITEM,
		QTY DECIMAL(5),
		PRIMARY KEY (CHECK_NO, LINE_NO) )
		
	CREATE VIEW FULL_CHECK_DETAIL AS
	  SELECT * 
	  FROM RESTAURANT."SERVER" NATURAL JOIN 
	  RESTAURANT.CHECK_HEADER NATURAL JOIN 
	  RESTAURANT.MENU_ITEM_GROUP NATURAL JOIN 
	  RESTAURANT.MENU_ITEM NATURAL JOIN 
	  RESTAURANT.CHECK_DETAIL	
	  
	  
	GRANT SELECT ON MENU_ITEM_GROUP TO PUBLIC	
	GRANT SELECT ON MENU_ITEM TO PUBLIC	
	GRANT SELECT ON "SERVER" TO PUBLIC	
	GRANT SELECT ON CHECK_HEADER TO PUBLIC	
	GRANT SELECT ON CHECK_DETAIL TO PUBLIC	
	GRANT SELECT ON FULL_CHECK_DETAIL TO PUBLIC	
;
.

--Save the schema definition
COMMIT;

--Re-connect as the new user
CONNECT TO 'THINKSQL' USER 'RESTAURANT';

--Add menu item groups
INSERT INTO MENU_ITEM_GROUP (MENU_ITEM_GROUP_NO, MENU_ITEM_GROUP_NAME) VALUES (1, 'Starter');
INSERT INTO MENU_ITEM_GROUP (MENU_ITEM_GROUP_NO, MENU_ITEM_GROUP_NAME) VALUES (2, 'Main Course');
INSERT INTO MENU_ITEM_GROUP (MENU_ITEM_GROUP_NO, MENU_ITEM_GROUP_NAME) VALUES (3, 'Side-dish');
INSERT INTO MENU_ITEM_GROUP (MENU_ITEM_GROUP_NO, MENU_ITEM_GROUP_NAME) VALUES (4, 'Dessert');
INSERT INTO MENU_ITEM_GROUP (MENU_ITEM_GROUP_NO, MENU_ITEM_GROUP_NAME) VALUES (5, 'Soft drink');
INSERT INTO MENU_ITEM_GROUP (MENU_ITEM_GROUP_NO, MENU_ITEM_GROUP_NAME) VALUES (6, 'Beer');
INSERT INTO MENU_ITEM_GROUP (MENU_ITEM_GROUP_NO, MENU_ITEM_GROUP_NAME) VALUES (7, 'Wine');

--Add menu items
INSERT INTO MENU_ITEM (MENU_ITEM_NO, MENU_ITEM_NAME, MENU_ITEM_GROUP_NO, PRICE) VALUES (1, 'Soup of the Day', 1, 2.45);
INSERT INTO MENU_ITEM (MENU_ITEM_NO, MENU_ITEM_NAME, MENU_ITEM_GROUP_NO, PRICE) VALUES (2, 'Samosas', 1, 1.95);
INSERT INTO MENU_ITEM (MENU_ITEM_NO, MENU_ITEM_NAME, MENU_ITEM_GROUP_NO, PRICE) VALUES (3, 'Prawn Cocktail', 1, 2.95);

INSERT INTO MENU_ITEM (MENU_ITEM_NO, MENU_ITEM_NAME, MENU_ITEM_GROUP_NO, PRICE) VALUES (100, 'Lasagne', 2, 4.95);
INSERT INTO MENU_ITEM (MENU_ITEM_NO, MENU_ITEM_NAME, MENU_ITEM_GROUP_NO, PRICE) VALUES (101, 'Spaghetti Bolognese', 2, 1.95);
INSERT INTO MENU_ITEM (MENU_ITEM_NO, MENU_ITEM_NAME, MENU_ITEM_GROUP_NO, PRICE) VALUES (102, 'Paella', 2, 6.95);
INSERT INTO MENU_ITEM (MENU_ITEM_NO, MENU_ITEM_NAME, MENU_ITEM_GROUP_NO, PRICE) VALUES (103, 'Borsch', 2, 4.95);
INSERT INTO MENU_ITEM (MENU_ITEM_NO, MENU_ITEM_NAME, MENU_ITEM_GROUP_NO, PRICE) VALUES (104, 'Irish stew', 2, 3.95);
INSERT INTO MENU_ITEM (MENU_ITEM_NO, MENU_ITEM_NAME, MENU_ITEM_GROUP_NO, PRICE) VALUES (105, 'Kedgeree', 2, 4.99);
INSERT INTO MENU_ITEM (MENU_ITEM_NO, MENU_ITEM_NAME, MENU_ITEM_GROUP_NO, PRICE) VALUES (106, 'Boeuf Bourgignone', 2, 7.95);
INSERT INTO MENU_ITEM (MENU_ITEM_NO, MENU_ITEM_NAME, MENU_ITEM_GROUP_NO, PRICE) VALUES (107, 'Roast Beef and Yorkshire Pudding', 2, 6.45);
INSERT INTO MENU_ITEM (MENU_ITEM_NO, MENU_ITEM_NAME, MENU_ITEM_GROUP_NO, PRICE) VALUES (108, 'Chicken Madras', 2, 5.45);
INSERT INTO MENU_ITEM (MENU_ITEM_NO, MENU_ITEM_NAME, MENU_ITEM_GROUP_NO, PRICE) VALUES (109, 'Chicken Tikka Masala', 2, 5.95);

INSERT INTO MENU_ITEM (MENU_ITEM_NO, MENU_ITEM_NAME, MENU_ITEM_GROUP_NO, PRICE) VALUES (200, 'Boiled Rice', 3, 1.95);
INSERT INTO MENU_ITEM (MENU_ITEM_NO, MENU_ITEM_NAME, MENU_ITEM_GROUP_NO, PRICE) VALUES (201, 'Mashed Potato', 3, 1.45);

INSERT INTO MENU_ITEM (MENU_ITEM_NO, MENU_ITEM_NAME, MENU_ITEM_GROUP_NO, PRICE) VALUES (300, 'Red Wine', 7, 2.10);
INSERT INTO MENU_ITEM (MENU_ITEM_NO, MENU_ITEM_NAME, MENU_ITEM_GROUP_NO, PRICE) VALUES (301, 'White Wine', 7, 2.10);
INSERT INTO MENU_ITEM (MENU_ITEM_NO, MENU_ITEM_NAME, MENU_ITEM_GROUP_NO, PRICE) VALUES (302, 'Guinness', 6, 2.99);
INSERT INTO MENU_ITEM (MENU_ITEM_NO, MENU_ITEM_NAME, MENU_ITEM_GROUP_NO, PRICE) VALUES (303, 'Lager', 6, 1.85);
INSERT INTO MENU_ITEM (MENU_ITEM_NO, MENU_ITEM_NAME, MENU_ITEM_GROUP_NO, PRICE) VALUES (304, 'Lemonade', 5, 1.20);
INSERT INTO MENU_ITEM (MENU_ITEM_NO, MENU_ITEM_NAME, MENU_ITEM_GROUP_NO, PRICE) VALUES (305, 'Cola', 5, 1.20);

INSERT INTO MENU_ITEM (MENU_ITEM_NO, MENU_ITEM_NAME, MENU_ITEM_GROUP_NO, PRICE) VALUES (400, 'Ice Cream', 4, 2.99);


--Add servers
INSERT INTO "SERVER" (SERVER_NO, SERVER_NAME) VALUES (1, 'John Smith');
INSERT INTO "SERVER" (SERVER_NO, SERVER_NAME) VALUES (2, 'Mary Jones');

--Add checks
INSERT INTO CHECK_HEADER (CHECK_NO, SERVER_NO, START_TIME) VALUES (1, 1, TIMESTAMP '2001-01-12 11:55:12');
INSERT INTO CHECK_HEADER (CHECK_NO, SERVER_NO, START_TIME) VALUES (2, 1, TIMESTAMP '2001-01-12 12:07:34');
INSERT INTO CHECK_HEADER (CHECK_NO, SERVER_NO, START_TIME) VALUES (3, 1, TIMESTAMP '2001-01-12 13:24:39');
INSERT INTO CHECK_HEADER (CHECK_NO, SERVER_NO, START_TIME) VALUES (4, 2, TIMESTAMP '2001-01-12 13:45:17');
INSERT INTO CHECK_HEADER (CHECK_NO, SERVER_NO, START_TIME) VALUES (5, 1, TIMESTAMP '2001-01-12 13:46:09');

--Add check 1 details
INSERT INTO CHECK_DETAIL (CHECK_NO, LINE_NO, MENU_ITEM_NO, QTY) VALUES (1, 1, 3, 1);
INSERT INTO CHECK_DETAIL (CHECK_NO, LINE_NO, MENU_ITEM_NO, QTY) VALUES (1, 2, 104, 1);
INSERT INTO CHECK_DETAIL (CHECK_NO, LINE_NO, MENU_ITEM_NO, QTY) VALUES (1, 3, 300, 1);

--Add check 2 details
INSERT INTO CHECK_DETAIL (CHECK_NO, LINE_NO, MENU_ITEM_NO, QTY) VALUES (2, 1, 2, 1);
INSERT INTO CHECK_DETAIL (CHECK_NO, LINE_NO, MENU_ITEM_NO, QTY) VALUES (2, 2, 108, 2);
INSERT INTO CHECK_DETAIL (CHECK_NO, LINE_NO, MENU_ITEM_NO, QTY) VALUES (2, 3, 200, 2);
INSERT INTO CHECK_DETAIL (CHECK_NO, LINE_NO, MENU_ITEM_NO, QTY) VALUES (2, 4, 303, 1);
INSERT INTO CHECK_DETAIL (CHECK_NO, LINE_NO, MENU_ITEM_NO, QTY) VALUES (2, 5, 304, 1);

--Add check 3 details
INSERT INTO CHECK_DETAIL (CHECK_NO, LINE_NO, MENU_ITEM_NO, QTY) VALUES (3, 1, 100, 1);
INSERT INTO CHECK_DETAIL (CHECK_NO, LINE_NO, MENU_ITEM_NO, QTY) VALUES (3, 2, 106, 1);
INSERT INTO CHECK_DETAIL (CHECK_NO, LINE_NO, MENU_ITEM_NO, QTY) VALUES (3, 3, 201, 1);
INSERT INTO CHECK_DETAIL (CHECK_NO, LINE_NO, MENU_ITEM_NO, QTY) VALUES (3, 4, 301, 2);

--Add check 4 details
INSERT INTO CHECK_DETAIL (CHECK_NO, LINE_NO, MENU_ITEM_NO, QTY) VALUES (4, 1, 107, 2);
INSERT INTO CHECK_DETAIL (CHECK_NO, LINE_NO, MENU_ITEM_NO, QTY) VALUES (4, 2, 302, 1);
INSERT INTO CHECK_DETAIL (CHECK_NO, LINE_NO, MENU_ITEM_NO, QTY) VALUES (4, 3, 400, 1);

--Add check 5 details
INSERT INTO CHECK_DETAIL (CHECK_NO, LINE_NO, MENU_ITEM_NO, QTY) VALUES (5, 1, 106, 1);
INSERT INTO CHECK_DETAIL (CHECK_NO, LINE_NO, MENU_ITEM_NO, QTY) VALUES (5, 2, 107, 1);
INSERT INTO CHECK_DETAIL (CHECK_NO, LINE_NO, MENU_ITEM_NO, QTY) VALUES (5, 3, 201, 1);
INSERT INTO CHECK_DETAIL (CHECK_NO, LINE_NO, MENU_ITEM_NO, QTY) VALUES (5, 4, 200, 1);
INSERT INTO CHECK_DETAIL (CHECK_NO, LINE_NO, MENU_ITEM_NO, QTY) VALUES (5, 5, 300, 2);
INSERT INTO CHECK_DETAIL (CHECK_NO, LINE_NO, MENU_ITEM_NO, QTY) VALUES (5, 6, 304, 2);
INSERT INTO CHECK_DETAIL (CHECK_NO, LINE_NO, MENU_ITEM_NO, QTY) VALUES (5, 7, 400, 2);


--Save the details
COMMIT; 

--Now show the sample data
SELECT * FROM MENU_ITEM_GROUP;
SELECT * FROM MENU_ITEM;
SELECT * FROM "SERVER";
SELECT * FROM CHECK_HEADER;
SELECT * FROM CHECK_DETAIL;

--Show the joined sample data 
SELECT * FROM "SERVER" NATURAL JOIN CHECK_HEADER NATURAL JOIN MENU_ITEM_GROUP NATURAL JOIN MENU_ITEM NATURAL JOIN CHECK_DETAIL;
